# XChainPy2 Binance Smart Chain Client

XChainPy Binance Smart Chain Client is a Python library for interacting with Binance Smart Chain.
It is built on top of xchainpy2_ethereum library.

### Documentation

👉 https://xchainpy2.readthedocs.io/en/latest/packages/xchainpy2_bsc.html
